/*
 *     Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 *     Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 *     This library is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU Lesser General Public
 *     License as published by the Free Software Foundation; version 2.1 of the License.
 *
 *     This library is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *     Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public
 *     License along with this library; if not, write to the Free Software
 *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package edu.ucsc.its.temerity.core

import co.touchlab.kermit.CommonWriter
import co.touchlab.kermit.Logger
import co.touchlab.kermit.NoTagFormatter
import co.touchlab.kermit.Severity.Debug
import co.touchlab.kermit.loggerConfigInit
import co.touchlab.kermit.platformLogWriter

internal actual fun createCommonLogger(tag: String?, config: TemClientConfig?, supportKtxNotebook: Boolean): Logger = when (config) {
  null -> {
    Logger(
      config = loggerConfigInit(
        if (supportKtxNotebook) CommonWriter(NoTagFormatter) else platformLogWriter(NoTagFormatter),
        minSeverity = Debug,
      ),
      tag = tag ?: "TemerityLib",
    )
  }
  else -> {
    when (config.optDebugEnabled) {
      // If debug logging is enabled, create a logger which color prints to the console
      true -> {
        Logger(
          config = loggerConfigInit(
            if (supportKtxNotebook) CommonWriter(NoTagFormatter) else platformLogWriter(NoTagFormatter),
            minSeverity = Debug,
          ),
          tag = tag ?: "TemerityLib",
        )
      }
      // If debug logging is disabled, create a logger which prints to a log file
      false -> {
        Logger(
          config = loggerConfigInit(),
        )
      }
    }
  }
}
